@@ -449,6 +449,7 @@ BrowserGlue.prototype = {
                      getService(Ci.nsIPrefBranch);
 
     var importBookmarks = false;
+    var importBookmarksHTML = false;
     var restoreDefaultBookmarks = false;
     try {
       restoreDefaultBookmarks = prefBranch.getBoolPref("browser.bookmarks.restore_default_bookmarks");
@@ -462,7 +463,8 @@ BrowserGlue.prototype = {
     }
     else {
       try {
-        importBookmarks = prefBranch.getBoolPref("browser.places.importBookmarksHTML");
+        importBookmarks = importBookmarksHTML =
+          prefBranch.getBoolPref("browser.places.importBookmarksHTML");
       } catch(ex) {}
     }
 
@@ -506,11 +508,12 @@ BrowserGlue.prototype = {
           // Report the error, but ignore it.
           Cu.reportError(err);
         }
-        prefBranch.setBoolPref("browser.places.importBookmarksHTML", false);
-        if (restoreDefaultBookmarks)
-          prefBranch.setBoolPref("browser.bookmarks.restore_default_bookmarks",
-                                 false);
       }
+      if (importBookmarksHTML)
+        prefBranch.setBoolPref("browser.places.importBookmarksHTML", false);
+      if (restoreDefaultBookmarks)
+        prefBranch.setBoolPref("browser.bookmarks.restore_default_bookmarks",
+                               false);
     }
 
     // Initialize bookmark archiving on idle.
@@ -797,7 +800,7 @@ BrowserGlue.prototype = {
     }
   },
 
-//@line 848 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/nsBrowserGlue.js"
+//@line 851 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/nsBrowserGlue.js"
 
   // this returns the most recent non-popup browser window
   _getMostRecentBrowserWindow : function ()
@@ -805,7 +808,7 @@ BrowserGlue.prototype = {
     var wm = Cc["@mozilla.org/appshell/window-mediator;1"].
              getService(Components.interfaces.nsIWindowMediator);
 
-//@line 856 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/nsBrowserGlue.js"
+//@line 859 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/nsBrowserGlue.js"
     var win = wm.getMostRecentWindow("navigator:browser", true);
 
     // if we're lucky, this isn't a popup, and we can just return this
@@ -819,7 +822,7 @@ BrowserGlue.prototype = {
           win = nextWin;
       }
     }
-//@line 882 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/nsBrowserGlue.js"
+//@line 885 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/nsBrowserGlue.js"
 
     return win;
   },
